![Logo](https://raw.githubusercontent.com/OpenHD/Open.HD/master/wiki-content/Open.HD%20Logo%20Splashscreen/Plain_OpenHD_Logo.jpg)

# Notes on weight

- A slimmed down Pi Zero is 7g (without hdmi and usb connectors)
- A Pi Zero cam is 1g
- Netgear A6100 is also 1g
